@@ -26,8 +26,8 @@ LOG = logging.getLogger(__name__)
 def get_options():
     return [
         cfg.StrOpt('user-id', help='User id'),
-        cfg.StrOpt('user-name', dest='username', help='Username',
-                   deprecated_name='username'),
+        cfg.StrOpt('username', dest='username', help='Username',
+                   deprecated_name='user-name'),
         cfg.StrOpt('user-domain-id', help="User's domain id"),
         cfg.StrOpt('user-domain-name', help="User's domain name"),
         cfg.StrOpt('password', help="User's password"),
@@ -82,3 +82,11 @@ class Password(base.BaseGenericPlugin):
         options = super(Password, cls).get_options()
         options.extend(get_options())
         return options
+
+    @classmethod
+    def load_from_argparse_arguments(cls, namespace, **kwargs):
+        if not (kwargs.get('password') or namespace.os_password):
+            kwargs['password'] = utils.prompt_user_password()
+
+        return super(Password, cls).load_from_argparse_arguments(namespace,
+                                                                 **kwargs)
